{
  pkgs,
    osConfig,
    lib,
    ...
}: {
  home.packages = with pkgs; [
    w3m
      inetutils
  ];

  services = {
# mbsync = {
#   enable = true;
#   frequency = "*-*-* *:*/5:00";
#   postExec = "\${pkgs.notmuch} new";
# };
    vdirsyncer = {
      enable = true;
#frequency = "*-*-* *:*/5:00";
    };
  };

  programs = {
    aerc = {
      enable = true;
      extraConfig = {
        ui = {
          sort = "-r arrival";
          threading-enabled = true;
          fuzzy-complete = true;
        };
        general = {
          default-save-path = "~/Downloads";
          log-file = "~/.aerc.log";
          unsafe-accounts-conf = true;
        };
        compose = {
          address-book-cmd = "notmuch address \"%s\"";
        };
        filters = {
          "text/plain" = "colorize";
          "text/calendar" = "calendar";
          "text/html" = "html | colorize";
        };
      };
    };
    msmtp = {
      enable = true;
    };
    mbsync = {
      enable = true;
    };
    lieer = {
      enable = true;
    };
    vdirsyncer = {
      enable = true;
    };
    khal = {
      enable = true;
    };
    khard = {
      enable = true;
    };
    mu = {
      enable = true;
    };
    notmuch = {
      enable = true;
      new.tags = [ "new" ];
      hooks = {
        postNew = ''
          notmuch tag +sent -new tag:new from:mthomson@konradgroup.com

          notmuch tag +cal attachment:.ics

          notmuch tag +inbox +unread -new "tag:new"
          '';
        preNew = ''
          cd ~/Maildir/work/ && gmi sync
          '';
      };
    };
  };

  accounts = {
    email = {
      accounts.work = {
        primary = true;
        flavor = "gmail.com";
        address = "mthomson@konradgroup.com";
        realName = "Michael Thomson";
        aerc = {
          enable = true;
          extraAccounts = {
            source = "maildir://~/Maildir/work";
          };
        };
        notmuch = {
          enable = true;
        };
        lieer = {
          enable = true;
          settings = {
            replace_slash_with_dot = true;
            ignore_tags = [ "new" "personal" "work" ];
          };
        };
      };
    };
  };
}
